@@ -25,7 +25,7 @@ C   sw       array of "smoothed" weights dim(dls,dls) dls=2*(ih+ihw)+1
 C
 C   temporary arrays set for maximum degree 2
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       external kldistp,lkern
       double precision kldistp,lkern
@@ -276,7 +276,7 @@ C   sw       array of "smoothed" weights dim(dls,dls) dls=2*(ih+ihw)+1
 C
 C   temporary arrays set for maximum degree 2
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       external kldistp,lkern
       double precision kldistp,lkern
@@ -488,7 +488,7 @@ C   sw       array of "smoothed" weights dim(dls,dls) dls=2*(ih+ihw)+1
 C
 C   temporary arrays set for maximum degree 2
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       external kldistp,lkern
       double precision kldistp,lkern
@@ -763,7 +763,7 @@ C   sw       array of "smoothed" weights dim(dls,dls) dls=2*(ih+ihw)+1
 C
 C   temporary arrays set for maximum degree 2
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       external kldistp,lkern
       double precision kldistp,lkern
