@@ -784,7 +784,7 @@ C   bi       \sum  Wi   (output)
 C   thnew    \sum  Wi Y / bi     (output)
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores,pos(*)
@@ -945,7 +945,7 @@ C   bi       \sum  Wi   (output)
 C   thnew    \sum  Wi Y / bi     (output)
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores,nvd,pos(*)
