@@ -19,7 +19,7 @@ C   ncores   number of cores
 C
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores
