@@ -44,6 +44,7 @@ C   kern     specifies the location kernel
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C   npsize       patch size
 C
+!$      use omp_lib
       implicit none
 
       external kldist,lkern
@@ -230,7 +231,7 @@ C   bi       \sum  Wi   (output)
 C   thnew    \sum  Wi Y / bi     (output)
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores,pos(*)
@@ -419,7 +420,7 @@ C   bi       \sum  Wi   (output)
 C   thnew    \sum  Wi Y / bi     (output)
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores,nvd,pos(*)
@@ -609,7 +610,7 @@ C   bi       \sum  Wi   (output)
 C   thnew    \sum  Wi Y / bi     (output)
 C   wght     scaling factor for second and third dimension (larger values shrink)
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
 
       integer nv,n1,n2,n3,ncores,nvd,nd,pos(*)
