@@ -347,7 +347,7 @@ C   lwght    array for non-adaptive weights (auxiliary)
 C   wght     rations of voxel dimensions
 C   resi     auxilary array
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer n1,n2,n3,n4,kern,skern,wlse,pos(*)
       logical aws
@@ -482,7 +482,7 @@ C   lwght    array for non-adaptive weights (auxiliary)
 C   wght     rations of voxel dimensions
 C   swjy     auxilary array
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer dv,n1,n2,n3,kern,skern,ncores,wlse,pos(*)
       logical aws
