@@ -67,7 +67,7 @@ C   3D median smoother of y with neighborhood defined by ind
 C   results in yout
 C   size of work needs to be 2*nind
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer n1,n2,n3,nind,ind(3,nind),ncores
       integer mask(n1,n2,n3)
@@ -137,7 +137,7 @@ C   location weights in w(i)
 C   ind(.,i)[1:3] are j1-i1,j2-i2 and j3-i3 respectively
 C   wad, sad - array for weights>0 and corresponding observed s
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw),nthreds,iL,nfb
       integer mask(n1,n2,n3)
@@ -269,7 +269,7 @@ C   location weights in w(i)
 C   ind(.,i)[1:3] are j1-i1,j2-i2 and j3-i3 respectively
 C   wad, sad - array for weights>0 and corresponding observed s
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw)
       integer mask(n1,n2,n3)
@@ -436,7 +436,7 @@ C   ind(.,i) contains coordinate indormation corresponding to positive
 C   location weights in w(i)
 C   ind(.,i)[1:5] are j1-i1,j2-i2,j3-i3, i4 and j4 respectively
 C
-      use omp_lib
+!$      use omp_lib
       implicit none
       integer n1,n2,n3,nw,ind(3,nw),nthreds
       integer mask(n1,n2,n3)
